Corrfunc package
================

.. automodule:: Corrfunc
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::

   Corrfunc.mocks
   Corrfunc.theory

Corrfunc.io module
------------------

.. automodule:: Corrfunc.io
   :members:
   :undoc-members:
   :show-inheritance:

Corrfunc.utils module
---------------------

.. automodule:: Corrfunc.utils
   :members:
   :undoc-members:
   :show-inheritance:

